@@ -2,14 +2,14 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from .purchase import *
+from . import purchase
 
 
 def register():
     Pool.register(
-        Purchase,
-        PurchaseIgnoredInvoiceLine,
+        purchase.Purchase,
+        purchase.PurchaseIgnoredInvoiceLine,
         module='purchase_invoice_line_standalone', type_='model')
     Pool.register(
-        HandleInvoiceException,
+        purchase.HandleInvoiceException,
         module='purchase_invoice_line_standalone', type_='wizard')
