@@ -1,18 +1,14 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import ModelSQL, fields
-from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 
-__all__ = ['Purchase', 'PurchaseIgnoredInvoiceLine',
-    'HandleInvoiceException']
-
 
 class Purchase(metaclass=PoolMeta):
     __name__ = 'purchase.purchase'
-    invoice_lines = fields.Function(fields.One2Many('account.invoice.line',
-            None, 'Invoice Lines'), 'get_invoice_lines',
-        searcher='search_invoice_lines')
+    invoice_lines = fields.Function(fields.Many2Many(
+            'account.invoice.line', None, None, "Invoice Lines"),
+        'get_invoice_lines', searcher='search_invoice_lines')
     invoice_lines_ignored = fields.Many2Many(
             'purchase.purchase-ignored-account.invoice.line',
             'purchase', 'invoice', 'Invoice Lines Ignored', readonly=True)
@@ -38,8 +34,6 @@ class Purchase(metaclass=PoolMeta):
                 'invoice': None,
                 'invoice_type': invoice.type,
                 'party': invoice.party.id,
-                'currency': invoice.currency.id,
-                'company': invoice.company.id,
                 })
             InvoiceLine.delete(lines_to_delete)
             Invoice.cancel([invoice])
@@ -52,7 +46,7 @@ class Purchase(metaclass=PoolMeta):
         skips = set(x.id for x in self.invoice_lines_ignored)
         invoice_lines = [l for l in self.invoice_lines if l.id not in skips]
         if invoice_lines:
-            if any(l.invoice and l.invoice.state == 'cancel'
+            if any(l.invoice and l.invoice.state == 'cancelled'
                     for l in invoice_lines):
                 return 'exception'
             elif (state == 'paid'
@@ -87,19 +81,16 @@ class HandleInvoiceException(metaclass=PoolMeta):
     __name__ = 'purchase.handle.invoice.exception'
 
     def transition_handle(self):
-        Purchase = Pool().get('purchase.purchase')
-
         state = super(HandleInvoiceException, self).transition_handle()
 
-        purchase = Purchase(Transaction().context['active_id'])
         invoice_lines = []
-        for invoice_line in purchase.invoice_lines:
+        for invoice_line in self.record.invoice_lines:
             if (invoice_line.invoice
-                    and invoice_line.invoice.state == 'cancel'):
+                    and invoice_line.invoice.state == 'cancelled'):
                 invoice_lines.append(invoice_line.id)
         if invoice_lines:
-            Purchase.write([purchase], {
+            self.model.write([self.record], {
                     'invoice_lines_ignored': [('add', invoice_lines)],
                     })
-        Purchase.__queue__.process([purchase])
+        self.model.__queue__.process([self.record])
         return state
