@@ -2,7 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 
 try:
-    from trytond.modules.purchase_invoice_line_standalone.tests.test_purchase_invoice_line_standalone import suite
+    from trytond.modules.purchase_invoice_line_standalone.tests.test_purchase_invoice_line_standalone import suite  # noqa: E501
 except ImportError:
     from .test_purchase_invoice_line_standalone import suite
 
